@@ -51,12 +51,14 @@ define([
               , InitWhileBlockOption
               , InitLambdaBlockOption
                
-              , InitApiBlockOption
+              , ApiBlockOption
 
               , InitTextBlockOption
               , InitNodeBlockOption
               , InitNoneOption) {
 
+    const { InitAPIBlockOption, LoadAPIBlockOption } = ApiBlockOption;
+
     const {  SetChildBlockList_down_first_indent_last
 
             , MapTypeToName
@@ -66,6 +68,8 @@ define([
             , IsElifElseExceptFinallyBlockType
             , IsIfForTryBlockType
             
+            , GenerateApiCode
+
             , GenerateClassInParamList
             , GenerateDefCode
             , GenerateReturnCode
@@ -1070,34 +1074,38 @@ define([
                 }
                 break;
             }
-
+            case BLOCK_CODELINE_TYPE.TEXT: 
             case BLOCK_CODELINE_TYPE.API: {
                 // console.log('isRun',isRun);
                 vpCommon.setIsAPIListRunCode(isRun);
 
                 /** API List Pakage가 없을 때 */
                 if (!thisBlock.getImportPakage()) {
-                    return 'BREAK_RUN';
-                }
-                var apiListPackage = thisBlock.getImportPakage();
-                var generatedCode = apiListPackage.generateCode(false, false);
-                var apicode = '';
-                /** API List 에서 generatedCode가 없을 때 */
-                if (!generatedCode) {
-                    generatedCode = '';
+                    // console.log('no api list package');
+                    // return 'BREAK_RUN';
+                    // TODO: 없으면 기존 metadata의 code로 처리
+                    codeLine += GenerateApiCode(thisBlock);
                 } else {
-                    apicode = MapNewLineStrToIndentString( generatedCode, 
-                                                           indentString);
-                }
- 
-                apiListPackage.metaSave();   
-                apiListPackage.metaGenerate(); 
-
-                /** API List 에서 BREAK_RUN을 리턴할 때 */
-                if (apicode.indexOf('BREAK_RUN') != -1) {
-                    return 'BREAK_RUN';
-                } else {
-                    codeLine += apicode;
+                    var apiListPackage = thisBlock.getImportPakage();
+                    var generatedCode = apiListPackage.generateCode(false, false);
+                    var apicode = '';
+                    /** API List 에서 generatedCode가 없을 때 */
+                    if (!generatedCode) {
+                        generatedCode = '';
+                    } else {
+                        apicode = MapNewLineStrToIndentString( generatedCode, 
+                                                               indentString);
+                    }
+     
+                    apiListPackage.metaSave();   
+                    apiListPackage.metaGenerate(); 
+    
+                    /** API List 에서 BREAK_RUN을 리턴할 때 */
+                    if (apicode.indexOf('BREAK_RUN') != -1) {
+                        return 'BREAK_RUN';
+                    } else {
+                        codeLine += apicode;
+                    }
                 }
 
                 break;
@@ -1149,10 +1157,6 @@ define([
                 codeLine += GenerateImportCode(thisBlock, indentString);
                 break;
             }
-            /** api */
-            case BLOCK_CODELINE_TYPE.API: {
-                break;
-            }
             /** try */
             case BLOCK_CODELINE_TYPE.TRY: {
                 codeLine += `${blockName.toLowerCase()}:`;
@@ -1617,7 +1621,7 @@ define([
 
             /** Api block */
             case BLOCK_CODELINE_TYPE.API: {
-                InitApiBlockOption(thisBlock, optionPageSelector);
+                InitAPIBlockOption(thisBlock, optionPageSelector);
                 break;
             }
 
@@ -1648,6 +1652,17 @@ define([
         blockContainerThis.reRenderOptionDomPool(blockOptionPageDom);
     }
 
+    Block.prototype.renderApiOption = function() {
+        var thisBlock = this;
+        var blockContainerThis = this.getBlockContainerThis();
+        var optionPageSelector = blockContainerThis.getOptionPageSelector();
+        var blockUUID = this.getUUID();
+        var blockOptionPageDom = blockContainerThis.getOptionDom(blockUUID);
+        var blockType = thisBlock.getBlockType();
+
+        LoadAPIBlockOption(thisBlock, optionPageSelector);
+    }
+
     Block.prototype.resetOptionPage = function() {
         var blockContainerThis = this.getBlockContainerThis();
         var blockUUID = this.getUUID();
@@ -1726,13 +1741,17 @@ define([
     /** ---------------------------이벤트 함수 바인딩--------------------------- */
     Block.prototype.bindEventAll = function() {
         var blockType = this.getBlockType();
-        /** text 블럭이나 elif else except finally 블럭일 경우 Drag 이동 금지 */
-        if ( IsElifElseExceptFinallyBlockType(blockType) == true 
-            || blockType == BLOCK_CODELINE_TYPE.TEXT) {
+        /** elif else except finally 블럭일 경우 Drag 이동 금지 */
+        if ( IsElifElseExceptFinallyBlockType(blockType) == true ) {
+            this.bindClickEvent();
+            this.bindLineNumberEvent();
+        } else if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
+        /** text 블럭일 경우 */
+            this.bindDragEvent();   // 추가: Text Block Drag 가능하도록
             this.bindClickEvent();
             this.bindLineNumberEvent();
         /** node 블럭일 경우 */
-        } else if(blockType == BLOCK_CODELINE_TYPE.NODE) {
+        } else if (blockType == BLOCK_CODELINE_TYPE.NODE) {
             // this.bindClickEvent();
             this.bindDragEvent();
             this.bindNodeBlockClickEvent_text();
@@ -2337,9 +2356,11 @@ define([
         var blockUUID = this.getUUID();
         var blockContainerThis = this.getBlockContainerThis();
         var importPakage = this.getImportPakage();
-        console.log('importPakage',importPakage);
-        importPakage.generateCode(false, false);
+        
+        // get generatedCode and save as metadata
+        var code = importPakage.generateCode(false, false);
         importPakage.metaGenerate();
+        importPakage.metadata.code = code;
 
         blockContainerThis.removeOptionDom(blockUUID);
         var generatedMetaData = importPakage.metadata;
