@@ -14,9 +14,14 @@ define([
     , './api_list.js'
 
     , './component/boardMenuBar.js'
+    // TEST: File Navigation
+    , 'nbextensions/visualpython/src/common/vpFileNavigation'
 ], function ( $, vpCommon, vpConst, vpContainer, 
               api, constData, blockContainer, createBlockBtn, createApiBtn, createGroup, api_list,
-              apiBlockMenuInit ) {
+              apiBlockMenuInit
+              // TEST: File Navigation
+              , FileNavigation
+              ) {
  
     const { IsCodeBlockType, ControlToggleInput, LoadVariableList, MapGroupTypeToName } = api;
   
@@ -33,6 +38,7 @@ define([
             , VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON
             , VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON
             , VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT 
+            , VP_ID_APIBLOCK_BOARD_MAKE_NODE_PATH
             , VP_ID_APIBLOCK_DELETE_BLOCK_ALL
 
             , VP_CLASS_PREFIX
@@ -302,6 +308,12 @@ define([
             }
         });
 
+        /** Board File Name changed */
+        $(vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT)).change(function(event) {
+            // reset path
+            $(vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_PATH)).val('');
+        });
+
         /** API List를 클릭했을 때*/
         $(vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_LEFT_TAP_APILIST_PAGE)).click(function(event) {
             blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.API_LIST_TAB);
@@ -430,6 +442,16 @@ define([
         /** 햄버거 메뉴 save 저장 클릭 */
         $(document).on(STR_CLICK, vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.VP_NOTE_EXTRA_MENU_SAVE_NOTE)), function() {
             var saveFileName = $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val();
+            var saveFilePath = $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_PATH).val(); // path
+
+            // TEST: File Navigation
+            // var state = {
+
+            // };
+            // var fileNavigation = new FileNavigation(FileNavigation.FILE_TYPE.SAVE_VP_NOTE, state);
+
+            // return;
+
             /** 빈 string이거나 
              *  Untitled이면 File navigation을 open */
             if ( saveFileName == STR_EMPTY
@@ -438,14 +460,20 @@ define([
                 closeNoteExtraMenu();
             /** File navigation을 open하지 않고 alert창 띄움*/
             } else {
-                var saveFilePath = vpCommon.formatString("./{0}.{1}", saveFileName, vpConst.VP_NOTE_EXTENSION);
-                apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}.vp'`,['Yes', 'No', 'Cancel'], [() => {
+                if (!saveFilePath.includes(saveFileName)) {
+                    // 다른 파일이면 save as
+                    saveAsNotePage();
+                    closeNoteExtraMenu();
+                } else {
+                    var saveFilePath = vpCommon.formatString("{0}", saveFilePath, vpConst.VP_NOTE_EXTENSION);
                     saveNotePageAction_newVersion(vpCommon.formatString("{0}.{1}", saveFileName, vpConst.VP_NOTE_EXTENSION), saveFilePath);
-                },() => {
-    
-                },() => {
-                    
-                }]);
+                    // apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}.vp'`,['Yes', 'No', 'Cancel'], [() => {
+                    // },() => {
+        
+                    // },() => {
+                        
+                    // }]);
+                }
             }
         });
 
@@ -473,13 +501,14 @@ define([
             if (e.path.substring(e.path.lastIndexOf(".") + 1) === vpConst.VP_NOTE_EXTENSION) {
                 var selectedPath = $(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.VP_NOTE_REAL_FILE_PATH))).val();
                 var saveFileName = selectedPath.substring(selectedPath.lastIndexOf("/") + 1);
-                apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}'`,['Yes','No', 'Cancel'], [() => {
-                    saveNotePageAction_newVersion(saveFileName, selectedPath);
-                },() => {
+                // FIXME: 여기부분 수정해야 함
+                saveNotePageAction_newVersion(saveFileName, selectedPath);
+                // apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}'`,['Yes','No', 'Cancel'], [() => {
+                // },() => {
 
-                },() => {
+                // },() => {
 
-                }]);
+                // }]);
             }
         });
 
